==> nextcloud-23.0.12p1.tgz: nextcloud/apps/sharebymail/l10n/sr.js <==
OC.L10N.register(
    "sharebymail",
    {
    "Shared with %1$s" : "Подељено са %1$s",
    "Shared with {email}" : "Подељено са {email}",
    "Shared with %1$s by %2$s" : "%2$s поделио са %1$s",
    "Shared with {email} by {actor}" : "{actor} поделио са {email}",
    "Unshared from %1$s" : "Уклоњено дељење са %1$s",
    "Unshared from {email}" : "Уклоњено дељење са {email}",
    "Unshared from %1$s by %2$s" : "Уклоњено дељење са %1$s од стране %2$s",
    "Unshared from {email} by {actor}" : "Уклоњено дељење са {email} од стране {actor}",
    "Password for mail share sent to %1$s" : "Лозинка за дељење е-поштом послата на %1$s",
    "Password for mail share sent to {email}" : "Лозинка за дељење е-поштом послата на {email}",
    "Password for mail share sent to you" : "Лозинка за дељење е-поштом послата Вама",
    "You shared %1$s with %2$s by mail" : "Поделили сте %1$s са %2$s е-поштом",
    "You shared {file} with {email} by mail" : "Поделили сте {file} са {email} е-поштом",
    "%3$s shared %1$s with %2$s by mail" : "%3$s је поделио %1$s са %2$s е-поштом",
    "{actor} shared {file} with {email} by mail" : "{actor} је поделио {file} са {email} е-поштом",
    "You unshared %1$s from %2$s by mail" : "Мејлом сте уклонили дељење фајла %1$s преко адресе %2$s",
    "You unshared {file} from {email} by mail" : "Мејлом сте уклонили дељење фајла {file} преко адресе {email}",
    "%3$s unshared %1$s from %2$s by mail" : "%3$s је мејлом уклонио дељење фајла %1$s преко адресе %2$s",
    "{actor} unshared {file} from {email} by mail" : "{actor}  је мејлом уклонио дељење фајла {file} преко адресе {email}",
    "Password to access %1$s was sent to %2s" : "Лозинка за приступ %1$s је послата на %2s",
    "Password to access {file} was sent to {email}" : "Лозинка за приступ {file} је послата на {email}",
    "Password to access %1$s was sent to you" : "Лозинка за приступ %1$sВам је послата",
    "Password to access {file} was sent to you" : "Лозинка за приступ  {file} Вам је послата ",
    "Share by mail" : "Подели е-поштом",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Дељење %1$s није успело зато што се ова ставка већ дели са корисником %2$s",
    "Failed to send share by email" : "Грешка у слању дељења е-поштом",
    "%1$s shared »%2$s« with you" : "%1$s је поделио „%2$s“ са Вама",
    "%1$s shared »%2$s« with you." : "%1$s је поделио „%2$s“ са Вама.",
    "Click the button below to open it." : "Кликните на дугме испод да га отворите.",
    "Open »%s«" : "Отвори „%s“",
    "%1$s via %2$s" : "%1$s преко %2$s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate mail with a link to access it.\n" : "%1$s је поделио „%2$s“ са Вама.\nТреба да сте до сад добили посебни мејл са везом како да му приступите.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate mail with a link to access it." : "%1$s је поделио „%2$s“ са Вама. Треба да сте до сад добили посебни мејл са везом како да му приступите.",
    "Password to access »%1$s« shared to you by %2$s" : "%2$s Вам је поделио/ла лозинку за приступ „%1$s“",
    "Password to access »%s«" : "Лозинка за приступ „%s“",
    "It is protected with the following password:" : "Заштићена је следећом лозинком:",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s је поделио „%2$s“ са Вама и жели да дода:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s је поделио „%2$s“ са Вама и жели да дода",
    "»%s« added a note to a file shared with you" : "„%s“ је додао белешку на фајл који дели са Вама",
    "You just shared »%1$s« with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "Управо сте поделили „%1$s“ са корисником %2$s. Дељење је већ послато примаоцу. Због безбедоносне политике коју је дефинисао администратор инстанце %3$s, свако дељење мора бити заштићено лозинком и није дозвољено да пошаљете лозинку директно кориснику. Због тога морате ручно послати лозинку примаоцу.",
    "Password to access »%1$s« shared by you with %2$s" : "Корисник %2$s је поделио са Вама лозинку за приступ „%1$s“",
    "This is the password:" : "Ово је лозинка:",
    "You can choose a different password at any time in the share dialog." : "Можете да одаберете другу лозинку кад год желите у дијалогу за дељење.",
    "Could not find share" : "Не могу да пронађем дељење",
    "Share provider which allows you to share files by mail" : "Добављач дељења који Вам дозвољава дељење е-поштом",
    "Allows users to share a personalized link to a file or folder by putting in an email address." : "Дозволи корисницима да поделе персонализовану везу до фајла или фасцикле уносом е-адресе.",
    "Send password by mail" : "Пошаљи лозинку е-поштом"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-24.0.10.tgz: nextcloud/apps/sharebymail/l10n/sr.js <==
OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Подељено са {email}",
    "Shared with {email} by {actor}" : "{actor} поделио са {email}",
    "Unshared from {email}" : "Уклоњено дељење са {email}",
    "Unshared from {email} by {actor}" : "Уклоњено дељење са {email} од стране {actor}",
    "Password for mail share sent to {email}" : "Лозинка за дељење е-поштом послата на {email}",
    "Password for mail share sent to you" : "Лозинка за дељење е-поштом послата Вама",
    "You shared {file} with {email} by mail" : "Поделили сте {file} са {email} е-поштом",
    "{actor} shared {file} with {email} by mail" : "{actor} је поделио {file} са {email} е-поштом",
    "You unshared {file} from {email} by mail" : "Мејлом сте уклонили дељење фајла {file} преко адресе {email}",
    "{actor} unshared {file} from {email} by mail" : "{actor}  је мејлом уклонио дељење фајла {file} преко адресе {email}",
    "Password to access {file} was sent to {email}" : "Лозинка за приступ {file} је послата на {email}",
    "Password to access {file} was sent to you" : "Лозинка за приступ  {file} Вам је послата ",
    "Share by mail" : "Подели е-поштом",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Дељење %1$s није успело зато што се ова ставка већ дели са корисником %2$s",
    "Failed to send share by email" : "Грешка у слању дељења е-поштом",
    "%1$s shared »%2$s« with you" : "%1$s је поделио „%2$s“ са Вама",
    "%1$s shared »%2$s« with you." : "%1$s је поделио „%2$s“ са Вама.",
    "Click the button below to open it." : "Кликните на дугме испод да га отворите.",
    "Open »%s«" : "Отвори „%s“",
    "%1$s via %2$s" : "%1$s преко %2$s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate mail with a link to access it.\n" : "%1$s је поделио „%2$s“ са Вама.\nТреба да сте до сад добили посебни мејл са везом како да му приступите.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate mail with a link to access it." : "%1$s је поделио „%2$s“ са Вама. Треба да сте до сад добили посебни мејл са везом како да му приступите.",
    "Password to access »%1$s« shared to you by %2$s" : "%2$s Вам је поделио/ла лозинку за приступ „%1$s“",
    "Password to access »%s«" : "Лозинка за приступ „%s“",
    "It is protected with the following password:" : "Заштићена је следећом лозинком:",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s је поделио „%2$s“ са Вама и жели да дода:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s је поделио „%2$s“ са Вама и жели да дода",
    "»%s« added a note to a file shared with you" : "„%s“ је додао белешку на фајл који дели са Вама",
    "You just shared »%1$s« with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "Управо сте поделили „%1$s“ са корисником %2$s. Дељење је већ послато примаоцу. Због безбедоносне политике коју је дефинисао администратор инстанце %3$s, свако дељење мора бити заштићено лозинком и није дозвољено да пошаљете лозинку директно кориснику. Због тога морате ручно послати лозинку примаоцу.",
    "Password to access »%1$s« shared by you with %2$s" : "Корисник %2$s је поделио са Вама лозинку за приступ „%1$s“",
    "This is the password:" : "Ово је лозинка:",
    "You can choose a different password at any time in the share dialog." : "Можете да одаберете другу лозинку кад год желите у дијалогу за дељење.",
    "Could not find share" : "Не могу да пронађем дељење",
    "Share provider which allows you to share files by mail" : "Добављач дељења који Вам дозвољава дељење е-поштом",
    "Allows users to share a personalized link to a file or folder by putting in an email address." : "Дозволи корисницима да поделе персонализовану везу до фајла или фасцикле уносом е-адресе.",
    "Send password by mail" : "Пошаљи лозинку е-поштом",
    "Shared with %1$s" : "Подељено са %1$s",
    "Shared with %1$s by %2$s" : "%2$s поделио са %1$s",
    "Unshared from %1$s" : "Уклоњено дељење са %1$s",
    "Unshared from %1$s by %2$s" : "Уклоњено дељење са %1$s од стране %2$s",
    "Password for mail share sent to %1$s" : "Лозинка за дељење е-поштом послата на %1$s",
    "You shared %1$s with %2$s by mail" : "Поделили сте %1$s са %2$s е-поштом",
    "%3$s shared %1$s with %2$s by mail" : "%3$s је поделио %1$s са %2$s е-поштом",
    "You unshared %1$s from %2$s by mail" : "Мејлом сте уклонили дељење фајла %1$s преко адресе %2$s",
    "%3$s unshared %1$s from %2$s by mail" : "%3$s је мејлом уклонио дељење фајла %1$s преко адресе %2$s",
    "Password to access %1$s was sent to %2s" : "Лозинка за приступ %1$s је послата на %2s",
    "Password to access %1$s was sent to you" : "Лозинка за приступ %1$sВам је послата"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
